@@ -1,8 +1,11 @@
-# Imports models
+"""
+Imports models.
+"""
+
 from .dvs.model_convtiny_gesture import (convtiny_dvs_gesture,
                                          convtiny_gesture_pretrained)
 from .dvs.model_convtiny_handy import (convtiny_dvs_handy,
-                                       convtiny_handy_pretrained)
+                                       convtiny_handy_samsung_pretrained)
 from .cifar10.model_ds_cnn import ds_cnn_cifar10, ds_cnn_cifar10_pretrained
 from .cifar10.model_vgg import vgg_cifar10, vgg_cifar10_pretrained
 from .imagenet.model_mobilenet import (mobilenet_imagenet,
@@ -16,3 +19,4 @@ from .cse2018.model_tse import tse_mlp_cse2018, tse_mlp_cse2018_pretrained
 from .tabular_data import tabular_data
 from .detection.model_yolo import (yolo_base, yolo_widerface_pretrained,
                                    yolo_voc_pretrained)
+from .gamma_constraint import add_gamma_constraint
