@@ -15,10 +15,10 @@
 # limitations under the License.
 # ******************************************************************************
 """
- akida_models main command-line interface
+akida_models main command-line interface
 
- This package entry-point allows akida models to be instantiated and saved at a
- specified location.
+This package entry-point allows akida models to be instantiated and saved at a
+specified location.
 
 """
 
@@ -36,6 +36,13 @@ from .dvs.model_convtiny_gesture import convtiny_dvs_gesture
 
 
 def main():
+    """ CLI entry point.
+
+    Contains an argument parser with specific arguments depending on the model
+    to be created. Complete arguments lists available using the -h or --help
+    argument.
+
+    """
     parser = argparse.ArgumentParser()
     sp = parser.add_subparsers(dest="action")
     c_parser = sp.add_parser("create", help="Create an akida Keras model")
