@@ -14,6 +14,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ******************************************************************************
+"""
+Module used to compute mAP scores for YOLO classification.
+"""
 
 import tensorflow as tf
 import numpy as np
@@ -68,7 +71,7 @@ class MapEvaluation(tf.keras.callbacks.Callback):
         self._max_box_per_image = max_box_per_image
         self._is_keras_model = is_keras_model
 
-    def on_epoch_end(self, epoch, logs={}):
+    def on_epoch_end(self, epoch, logs=None):
 
         if epoch % self._period == 0 and self._period != 0:
             _map, average_precisions = self.evaluate_map()
@@ -150,7 +153,8 @@ class MapEvaluation(tf.keras.callbacks.Callback):
             pred_labels = pred_labels[score_sort]
             pred_boxes = pred_boxes[score_sort]
 
-            # limit the number of predictions to max_box_per_image based on score
+            # limit the number of predictions to max_box_per_image based on
+            # score
             number_of_predictions = pred_boxes.shape[0]
             if number_of_predictions > self._max_box_per_image:
                 pred_labels = pred_labels[:self._max_box_per_image]
@@ -229,7 +233,8 @@ class MapEvaluation(tf.keras.callbacks.Callback):
 
         return average_precisions
 
-    def _compute_overlap(self, a, b):
+    @staticmethod
+    def _compute_overlap(a, b):
         """ Computes overlap between two boxes defined by their top left and
         bottom right corner coordinates.
         Code originally from https://github.com/rbgirshick/py-faster-rcnn.
@@ -260,7 +265,8 @@ class MapEvaluation(tf.keras.callbacks.Callback):
 
         return intersection / ua
 
-    def _compute_ap(self, recall, precision):
+    @staticmethod
+    def _compute_ap(recall, precision):
         """ Compute the average precision, given the recall and precision
         curves.
         Code originally from https://github.com/rbgirshick/py-faster-rcnn.
