@@ -14,6 +14,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ******************************************************************************
+"""
+Convtiny model definition for DVS gesture classification.
+"""
 
 # Tensorflow/Keras Imports
 from tensorflow.keras.utils import get_file
@@ -130,20 +133,27 @@ def convtiny_dvs_gesture(input_shape=(64, 64, 6),
                     add_batchnorm=False,
                     add_activation=False,
                     use_bias=False)
-    x = Activation('softmax', name='act_softmax')(x)
+    act_function = 'softmax' if classes > 1 else 'sigmoid'
+    x = Activation(act_function, name=f'act_{act_function}')(x)
     x = Reshape((classes,), name='reshape_2')(x)
 
     model = Model(inputs=img_input, outputs=x, name='dvs_network')
 
     if ((weight_quantization != 0) or (activ_quantization != 0)):
         return quantize(model, weight_quantization, activ_quantization)
-    else:
-        return model
+    return model
 
 
 def convtiny_gesture_pretrained():
+    """ Helper method to retrieve a `convtiny_dvs_gesture` model that was
+    trained on IBM DVS Gesture dataset.
+
+    Returns:
+        tf.keras.Model: a Keras Model instance.
+
+    """
     model_name = 'convtiny_dvs_gesture_iq2_wq2_aq4.h5'
-    file_hash = '2259AB9B15C63420EE21490CD8CA356B397D165FB0DAC4654BE99D0A8AE9B7BE'
+    file_hash = '2259ab9b15c63420ee21490cd8ca356b397d165fb0dac4654be99d0a8ae9b7be'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
                           file_hash=file_hash,
