@@ -14,6 +14,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ******************************************************************************
+"""
+Convtiny model definition for DVS handy classification.
+"""
 
 # Tensorflow/Keras Imports
 from tensorflow.keras.utils import get_file
@@ -35,7 +38,7 @@ NUM_SPIKING_NEURONS = 256
 BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/convtiny/'
 
 
-def convtiny_dvs_handy(input_shape=(64, 64, 2),
+def convtiny_dvs_handy(input_shape=(120, 160, 2),
                        classes=None,
                        weight_quantization=0,
                        activ_quantization=0):
@@ -155,20 +158,27 @@ def convtiny_dvs_handy(input_shape=(64, 64, 2),
                     add_activation=False,
                     use_bias=False)
 
-    x = Activation('softmax', name='act_softmax')(x)
+    act_function = 'softmax' if classes > 1 else 'sigmoid'
+    x = Activation(act_function, name=f'act_{act_function}')(x)
     x = Reshape((classes,), name='reshape_2')(x)
 
     model = Model(inputs=img_input, outputs=x, name='dvs_network')
 
     if ((weight_quantization != 0) or (activ_quantization != 0)):
         return quantize(model, weight_quantization, activ_quantization)
-    else:
-        return model
+    return model
 
 
-def convtiny_handy_pretrained():
-    model_name = 'convtiny_dvs_handy_iq2_wq2_aq4.h5'
-    file_hash = 'F155846C555FC2600CD50C805872E6707F88327F3D3ABB13E3A9B413F291BCEA'
+def convtiny_handy_samsung_pretrained():
+    """ Helper method to retrieve a `convtiny_dvs_handy` model that was trained
+    on samsung_handy dataset.
+
+    Returns:
+        tf.keras.Model: a Keras Model instance.
+
+    """
+    model_name = 'convtiny_dvs_handy_samsung_iq2_wq2_aq4.h5'
+    file_hash = '9f5f4c1b6b366b0450480df5903aa4bb764f09e1a8677e35fba55f69748930c6'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
                           file_hash=file_hash,
