@@ -27,13 +27,15 @@ Brainchip information:
 import struct
 import os
 import re
-import numpy as np
-
 import sys
 import tarfile
 import urllib
 import glob
 
+import numpy as np
+
+from dv import AedatFile
+
 # Global definition for AEDATv2
 EVENT_LENGTH = 8  # 1 event takes 8 bytes (64 bits)
 READ_MODE = '>II'  # struct.unpack(), 4 bytes + 4 bytes
@@ -59,14 +61,13 @@ def _parse_version_string(version_string):
     v4 = re.compile('.*#!AER-DAT4.*')
     if v2.match(str(version_string)):
         return 2
-    elif v3.match(str(version_string)):
+    if v3.match(str(version_string)):
         return 3
-    elif v4.match(str(version_string)):
+    if v4.match(str(version_string)):
         return 4
-    else:
-        raise ValueError("Unrecognized or unsupported version: %s" %
-                         str(version_string).strip(),
-                         file=sys.stderr)
+    raise ValueError("Unrecognized or unsupported version: %s" %
+                     str(version_string).strip(),
+                     file=sys.stderr)
 
 
 def _skip_ascii_header(file, version):
@@ -82,13 +83,12 @@ def _skip_ascii_header(file, version):
     bytes_pos = 0  # bytes position
     line = file.readline()
     bytes_pos += len(line)
-    if version == 2 or version == 3:
+    if version in [2, 3]:
         while line.startswith(b'#'):
             if line == b'#!END-HEADER\r\n':
                 break
-            else:
-                line = file.readline()
-                bytes_pos += len(line)
+            line = file.readline()
+            bytes_pos += len(line)
     elif version == 4:
         return bytes_pos
     else:
@@ -167,7 +167,7 @@ def _read_event_v3(file, bytes_pos, trial_times, subj_num, light_cond):
             break
 
         # read header
-        type = struct.unpack('H', header[0:2])[0]
+        header_type = struct.unpack('H', header[0:2])[0]
         size = struct.unpack('I', header[4:8])[0]
         tsoverflow = struct.unpack('I', header[12:16])[0]
         capacity = struct.unpack('I', header[16:20])[0]
@@ -176,7 +176,7 @@ def _read_event_v3(file, bytes_pos, trial_times, subj_num, light_cond):
         data = file.read(data_length)
         counter = 0
 
-        if type == 1:
+        if header_type == 1:
             while data[counter:counter + size]:
                 # unpack data from bytes
                 aer_data = struct.unpack('I', data[counter:counter + 4])[0]
@@ -215,27 +215,30 @@ def _read_event_v3(file, bytes_pos, trial_times, subj_num, light_cond):
                             if start_time < stop_time:
                                 print("Error on subject %d, with %s condition" %
                                       (subj_num, light_cond))
-                                raise Exception(
-                                    "New start time earlier than previous block stop time"
-                                )
+                                raise Exception("New start time earlier than \
+                                    previous block stop time")
                             stop_time = int(trial_times[trial_ind][2])
                         else:
                             return trials
         else:
             # non-polarity event packet, not implemented
             raise NotImplementedError("Non polarity event packet not supported")
-    return
+    return []
 
 
 def _read_aedat_v4(datafile):
-    from dv import AedatFile
 
     # create data lists
     ev_times = []
     events = []
 
     with AedatFile(datafile) as f:
-        np_events = np.hstack([packet for packet in f['events'].numpy()])
+        np_events = np.array([],
+                             dtype=[('timestamp', '<i8'), ('x', '<i2'),
+                                    ('y', '<i2'), ('polarity', 'i1'),
+                                    ('_p1', '<i2'), ('_p2', 'i1')])
+        for packet in f['events'].numpy():
+            np_events = np.hstack([np_events, packet])
 
         # access information of all events by type
         timestamps, x, y, polarities = np_events['timestamp'], np_events[
@@ -250,7 +253,7 @@ def get_gesture_data(dataset_name, datafile, labelfile=None):
     """Creates gesture data dictionary from aedat file.
 
     Args:
-        dataset_name (str): dataset name (dvs_gesture or dvs_handy).
+        dataset_name (str): dataset name (dvs_gesture or samsung_handy).
         datafile (str): absolute path to aedat file.
         labelfile (int): absolute path to related label file.
 
@@ -266,12 +269,7 @@ def get_gesture_data(dataset_name, datafile, labelfile=None):
 
     data = None
     if os.path.isfile(datafile):
-        if dataset_name == "dvs_handy":
-            # Get subject id and labels from filename
-            subj = int(os.path.basename(datafile)[4:6])
-            label = int(os.path.basename(datafile)[7:9])
-            lighting_condition = 'fluorescent'
-        elif dataset_name == "dvs_gesture":
+        if dataset_name == "dvs_gesture":
             with open(labelfile) as f:
                 # Get class labels and start/stop times from the labels.csv file
                 trial_times = [line.split(',') for line in f]
@@ -284,38 +282,37 @@ def get_gesture_data(dataset_name, datafile, labelfile=None):
             label = int(os.path.basename(datafile)[8:10])
             lighting_condition = 'fluorescent'
 
-        aef = open(datafile, 'rb')
-        version = _parse_version_string(aef.readline())
-        aef.seek(0, 0)  # rewind
-        bytes_pos = _skip_ascii_header(aef, version)
-        if version == 2:
-            # get file length
-            statinfo = os.stat(datafile)
-            file_length = statinfo.st_size
+        with open(datafile, 'rb') as aef:
+            version = _parse_version_string(aef.readline())
+            aef.seek(0, 0)  # rewind
+            bytes_pos = _skip_ascii_header(aef, version)
+            if version == 2:
+                # get file length
+                statinfo = os.stat(datafile)
+                file_length = statinfo.st_size
 
-            events, ev_times = _read_aedat_v2(aef, file_length, bytes_pos)
-            data = {
-                'label': label,
-                'subject': subj,
-                'lighting': lighting_condition,
-                'events': np.array(events, dtype=np.uint8),
-                'ev_times': np.array(ev_times) - ev_times[0]
-            }
-        elif version == 3:
-            data = _read_event_v3(aef, bytes_pos, trial_times, subj_num,
-                                  lighting_condition)
-        elif version == 4:
-            aef.close()
-            events, ev_times = _read_aedat_v4(datafile)
-            data = {
-                'label': label,
-                'subject': subj,
-                'lighting': lighting_condition,
-                'events': np.array(events, dtype=np.uint16),
-                'ev_times': np.array(ev_times) - ev_times[0]
-            }
-        else:
-            raise ValueError("Unsupported version: %d" % version)
+                events, ev_times = _read_aedat_v2(aef, file_length, bytes_pos)
+                data = {
+                    'label': label,
+                    'subject': subj,
+                    'lighting': lighting_condition,
+                    'events': np.array(events, dtype=np.uint8),
+                    'ev_times': np.array(ev_times) - ev_times[0]
+                }
+            elif version == 3:
+                data = _read_event_v3(aef, bytes_pos, trial_times, subj_num,
+                                      lighting_condition)
+            elif version == 4:
+                events, ev_times = _read_aedat_v4(datafile)
+                data = {
+                    'label': label,
+                    'subject': subj,
+                    'lighting': lighting_condition,
+                    'events': np.array(events, dtype=np.uint16),
+                    'ev_times': np.array(ev_times) - ev_times[0]
+                }
+            else:
+                raise ValueError("Unsupported version: %d" % version)
 
     return data
 
@@ -324,7 +321,7 @@ def generate_dataset(dataset_name, datadir, subject_list):
     """Generates data set for a subject id list.
 
     Args:
-        dataset_name (str): dataset name (dvs_gesture or dvs_handy).
+        dataset_name (str): dataset name (dvs_gesture or samsung_handy).
         datadir (str): filepath where aedat files are stored.
         subject_list (list): subject id list to compose the train/test set.
 
@@ -332,17 +329,7 @@ def generate_dataset(dataset_name, datadir, subject_list):
         list: dataset filled with all events data.
     """
     dataset = []
-    if dataset_name == "dvs_handy":
-        for subj in subject_list:
-            datafile = glob.glob(
-                os.path.join(datadir,
-                             'Gest' + '{0:0=2d}'.format(subj) + '*.aedat'))
-            datafile.sort()
-            for idx in range(len(datafile)):
-                data = get_gesture_data(dataset_name, datafile[idx])
-                if data:
-                    dataset.append(data)
-    elif dataset_name == "dvs_gesture":
+    if dataset_name == "dvs_gesture":
         for subj in subject_list:
             datafile = glob.glob(
                 os.path.join(datadir, 'DvsGesture',
@@ -353,8 +340,8 @@ def generate_dataset(dataset_name, datadir, subject_list):
             datafile.sort()
             labelfile.sort()
 
-            for idx in range(len(datafile)):
-                dataset_tmp = get_gesture_data(dataset_name, datafile[idx],
+            for idx, val in enumerate(datafile):
+                dataset_tmp = get_gesture_data(dataset_name, val,
                                                labelfile[idx])
                 for data_dict in dataset_tmp:
                     dataset.append(data_dict)
@@ -364,8 +351,8 @@ def generate_dataset(dataset_name, datadir, subject_list):
                 os.path.join(datadir,
                              'GestS' + '{0:0=2d}'.format(subj) + '*.aedat*'))
             datafile.sort()
-            for idx in range(len(datafile)):
-                data = get_gesture_data(dataset_name, datafile[idx])
+            for val in datafile:
+                data = get_gesture_data(dataset_name, val)
                 if data:
                     dataset.append(data)
     else:
@@ -402,11 +389,11 @@ def download_and_extract_dataset(data_url, dest_directory):
         try:
             filepath, _ = urllib.request.urlretrieve(data_url, filepath,
                                                      _progress)
-        except:
+        except Exception as e:
             raise RuntimeError(
                 f"Failed to download URL: {data_url} to folder: "
                 f"{filepath}\nPlease make sure you have enough free"
-                f" space and an internet connection")
+                f" space and an internet connection") from e
         print()
         statinfo = os.stat(filepath)
         print(f"Successfully downloaded {filename} ({statinfo.st_size} bytes)")
