@@ -15,6 +15,8 @@
 # limitations under the License.
 # ******************************************************************************
 """
+MobileNet model definition for ImageNet classification.
+
 MobileNet V1 is a general architecture and can be used for multiple use cases.
 
 This specific version includes parameter options to generate a mobilenet version
@@ -28,7 +30,7 @@ compatible for Akida with:
 import warnings
 
 # Tensorflow/Keras Imports
-from tensorflow.keras import Model
+from tensorflow.keras import Model, regularizers
 from tensorflow.keras.utils import get_file
 from tensorflow.keras.layers import Input, Reshape, Dropout, Activation
 
@@ -96,6 +98,7 @@ def mobilenet_imagenet(input_shape=None,
                        include_top=True,
                        pooling=None,
                        classes=1000,
+                       use_stride2=False,
                        weight_quantization=0,
                        activ_quantization=0,
                        input_weight_quantization=None):
@@ -124,6 +127,8 @@ def mobilenet_imagenet(input_shape=None,
               model will be a 2D tensor.
         classes (int): optional number of classes to classify images
             into, only to be specified if `include_top` is True.
+        use_stride2 (bool): optional, replace max pooling operations by stride 2
+            convolutions in layers separable 2, 4, 6 and 12.
         weight_quantization (int): sets all weights in the model to have
             a particular quantization bitwidth except for the weights in the
             first layer.
@@ -152,6 +157,18 @@ def mobilenet_imagenet(input_shape=None,
     if input_weight_quantization is None:
         input_weight_quantization = weight_quantization
 
+    # Define weight regularization, will apply to the first convolutional layer
+    # and to all pointwise weights of separable convolutional layers.
+    weight_regularizer = regularizers.l2(4e-5)
+
+    # Define stride 2 or max pooling
+    if use_stride2:
+        sep_conv_pooling = None
+        strides = 2
+    else:
+        sep_conv_pooling = 'max'
+        strides = 1
+
     # Determine proper input shape and default size.
     if input_shape is None:
         default_size = 224
@@ -182,7 +199,8 @@ def mobilenet_imagenet(input_shape=None,
                    use_bias=False,
                    strides=2,
                    add_batchnorm=True,
-                   add_activation=True)
+                   add_activation=True,
+                   kernel_regularizer=weight_regularizer)
 
     x = separable_conv_block(x,
                              filters=int(64 * alpha),
@@ -191,17 +209,20 @@ def mobilenet_imagenet(input_shape=None,
                              padding='same',
                              use_bias=False,
                              add_batchnorm=True,
-                             add_activation=True)
+                             add_activation=True,
+                             pointwise_regularizer=weight_regularizer)
 
     x = separable_conv_block(x,
                              filters=int(128 * alpha),
                              name='separable_2',
                              kernel_size=(3, 3),
                              padding='same',
-                             pooling='max',
+                             pooling=sep_conv_pooling,
+                             strides=strides,
                              use_bias=False,
                              add_batchnorm=True,
-                             add_activation=True)
+                             add_activation=True,
+                             pointwise_regularizer=weight_regularizer)
 
     x = separable_conv_block(x,
                              filters=int(128 * alpha),
@@ -210,17 +231,20 @@ def mobilenet_imagenet(input_shape=None,
                              padding='same',
                              use_bias=False,
                              add_batchnorm=True,
-                             add_activation=True)
+                             add_activation=True,
+                             pointwise_regularizer=weight_regularizer)
 
     x = separable_conv_block(x,
                              filters=int(256 * alpha),
                              name='separable_4',
                              kernel_size=(3, 3),
                              padding='same',
-                             pooling='max',
+                             pooling=sep_conv_pooling,
+                             strides=strides,
                              use_bias=False,
                              add_batchnorm=True,
-                             add_activation=True)
+                             add_activation=True,
+                             pointwise_regularizer=weight_regularizer)
 
     x = separable_conv_block(x,
                              filters=int(256 * alpha),
@@ -229,17 +253,20 @@ def mobilenet_imagenet(input_shape=None,
                              padding='same',
                              use_bias=False,
                              add_batchnorm=True,
-                             add_activation=True)
+                             add_activation=True,
+                             pointwise_regularizer=weight_regularizer)
 
     x = separable_conv_block(x,
                              filters=int(512 * alpha),
                              name='separable_6',
                              kernel_size=(3, 3),
                              padding='same',
-                             pooling='max',
+                             pooling=sep_conv_pooling,
+                             strides=strides,
                              use_bias=False,
                              add_batchnorm=True,
-                             add_activation=True)
+                             add_activation=True,
+                             pointwise_regularizer=weight_regularizer)
 
     x = separable_conv_block(x,
                              filters=int(512 * alpha),
@@ -248,7 +275,8 @@ def mobilenet_imagenet(input_shape=None,
                              padding='same',
                              use_bias=False,
                              add_batchnorm=True,
-                             add_activation=True)
+                             add_activation=True,
+                             pointwise_regularizer=weight_regularizer)
 
     x = separable_conv_block(x,
                              filters=int(512 * alpha),
@@ -257,7 +285,8 @@ def mobilenet_imagenet(input_shape=None,
                              padding='same',
                              use_bias=False,
                              add_batchnorm=True,
-                             add_activation=True)
+                             add_activation=True,
+                             pointwise_regularizer=weight_regularizer)
 
     x = separable_conv_block(x,
                              filters=int(512 * alpha),
@@ -266,7 +295,8 @@ def mobilenet_imagenet(input_shape=None,
                              padding='same',
                              use_bias=False,
                              add_batchnorm=True,
-                             add_activation=True)
+                             add_activation=True,
+                             pointwise_regularizer=weight_regularizer)
 
     x = separable_conv_block(x,
                              filters=int(512 * alpha),
@@ -275,7 +305,8 @@ def mobilenet_imagenet(input_shape=None,
                              padding='same',
                              use_bias=False,
                              add_batchnorm=True,
-                             add_activation=True)
+                             add_activation=True,
+                             pointwise_regularizer=weight_regularizer)
 
     x = separable_conv_block(x,
                              filters=int(512 * alpha),
@@ -284,17 +315,20 @@ def mobilenet_imagenet(input_shape=None,
                              padding='same',
                              use_bias=False,
                              add_batchnorm=True,
-                             add_activation=True)
+                             add_activation=True,
+                             pointwise_regularizer=weight_regularizer)
 
     x = separable_conv_block(x,
                              filters=int(1024 * alpha),
                              name='separable_12',
                              kernel_size=(3, 3),
                              padding='same',
-                             pooling='max',
+                             pooling=sep_conv_pooling,
+                             strides=strides,
                              use_bias=False,
                              add_batchnorm=True,
-                             add_activation=True)
+                             add_activation=True,
+                             pointwise_regularizer=weight_regularizer)
 
     # Last separable layer with global pooling
     layer_pooling = 'global_avg' if include_top or pooling == 'avg' else None
@@ -306,7 +340,8 @@ def mobilenet_imagenet(input_shape=None,
                              pooling=layer_pooling,
                              use_bias=False,
                              add_batchnorm=True,
-                             add_activation=True)
+                             add_activation=True,
+                             pointwise_regularizer=weight_regularizer)
 
     if include_top:
         shape = (1, 1, int(1024 * alpha))
@@ -321,8 +356,10 @@ def mobilenet_imagenet(input_shape=None,
                                  padding='same',
                                  use_bias=False,
                                  add_batchnorm=False,
-                                 add_activation=False)
-        x = Activation('softmax', name='act_softmax')(x)
+                                 add_activation=False,
+                                 pointwise_regularizer=weight_regularizer)
+        act_function = 'softmax' if classes > 1 else 'sigmoid'
+        x = Activation(act_function, name=f'act_{act_function}')(x)
         x = Reshape((classes,), name='reshape_2')(x)
 
     # Create model.
@@ -334,8 +371,7 @@ def mobilenet_imagenet(input_shape=None,
         (input_weight_quantization != 0)):
         return quantize(model, weight_quantization, activ_quantization,
                         input_weight_quantization)
-    else:
-        return model
+    return model
 
 
 def mobilenet_imagenet_pretrained(alpha=1.0):
@@ -351,14 +387,14 @@ def mobilenet_imagenet_pretrained(alpha=1.0):
 
     """
     if alpha == 1.0:
-        model_name = 'mobilenet_imagenet_iq8_wq4_aq4.h5'
-        file_hash = '07780D7B6A12B764AF1372D792BDF032301508FB997BFD044C397CA2C8AD5747'
+        model_name = 'mobilenet_imagenet_224_iq8_wq4_aq4.h5'
+        file_hash = 'd9eabb514a7db6d823ab108b0fbc64fe2872ad1113bd6c04c9a3329b6a41e135'
     elif alpha == 0.5:
-        model_name = 'mobilenet_imagenet_alpha_50_iq8_wq4_aq4.h5'
-        file_hash = '7370A0DAA39143280F2CFF55F750162BC6025B2EE1FFC6361347AB295A22818A'
+        model_name = 'mobilenet_imagenet_224_alpha_50_iq8_wq4_aq4.h5'
+        file_hash = '68cbbb4cf08d3ca6401695fc126a2efad381ae932d5e4661eea91077619dbe61'
     elif alpha == 0.25:
-        model_name = 'mobilenet_imagenet_alpha_25_iq8_wq4_aq4.h5'
-        file_hash = '906CB111AAAEB9979D8394D4A33756C439329EDE405041B0BEDD789C570D50B5'
+        model_name = 'mobilenet_imagenet_224_alpha_25_iq8_wq4_aq4.h5'
+        file_hash = 'c094be674a71ed4787694be7240fd97f36ee9526675b9974c0342e9db561c9c8'
     else:
         raise ValueError(
             f"Requested model with alpha={alpha} is not available.")
@@ -380,7 +416,7 @@ def mobilenet_cats_vs_dogs_pretrained():
 
     """
     model_name = 'mobilenet_cats_vs_dogs_iq8_wq4_aq4.h5'
-    file_hash = '85a169b78b426647a7cff3c4d6caf902dcfcb56ea41d5ea50455d7ae466bfdd3'
+    file_hash = 'b021fccaba676de9549430336ff27875a85b2aea7ca767a5e70a76185362fa4b'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
                           file_hash=file_hash,
