@@ -15,13 +15,7 @@
 # limitations under the License.
 # ******************************************************************************
 """
-KWS model training script
-
-This script can be used to reproduce the results of the saved DS-CNN/KWS
-quantized models.
-
-The training process uses a cyclical learning rate. The 'cyclic_lr.py' script
-is originated from https://github.com/bckenstler/CLR and is under MIT license.
+KWS model training script.
 """
 
 # System imports
@@ -41,6 +35,15 @@ from akida_models.cyclic_lr import CyclicLR
 
 
 def get_rescaled_dataset(a, b):
+    """ Loads and rescales KWS dataset.
+
+    Args:
+        a (int): rescale factor
+        b (int): rescale bias
+
+    Returns:
+        tuple: train data, train labels, validation data and validation labels
+    """
     # Load pre-processed dataset
     fname = get_file(
         fname='kws_preprocessed_all_words_except_backward_follow_forward.pkl',
@@ -49,9 +52,8 @@ def get_rescaled_dataset(a, b):
         cache_subdir=os.path.join('datasets', 'kws'))
 
     print('Loading pre-processed dataset...')
-    f = open(fname, 'rb')
-    [x_train_ak, y_train, x_val_ak, y_val, _, _, _, _] = pickle.load(f)
-    f.close()
+    with open(fname, 'rb') as f:
+        [x_train_ak, y_train, x_val_ak, y_val, _, _, _, _] = pickle.load(f)
 
     # For cnn2snn Keras training, data must be scaled (usually to [0,1])
     x_train_keras = \
@@ -63,6 +65,15 @@ def get_rescaled_dataset(a, b):
 
 
 def compile_model(model, learning_rate=1e-4):
+    """ Compiles the model.
+
+    Args:
+        model (tf.Keras.Model): the model to compile
+        learning_rate (float): the learning rate
+
+    Returns:
+        tf.Keras.Model: the compiled model
+    """
     # Initialize optimizer and compile model
     opt = Adam(lr=learning_rate)
     model.compile(loss='categorical_crossentropy',
@@ -72,6 +83,17 @@ def compile_model(model, learning_rate=1e-4):
 
 
 def train_model(model, x_train, y_train, x_val, y_val, batch_size, epochs):
+    """ Trains the model.
+
+    Args:
+         model (tf.Keras.Model): the model to train
+        x_train (numpy.ndarray): train data
+        y_train (numpy.ndarray): train labels
+        x_val (numpy.ndarray): validation data
+        y_val (numpy.ndarray): validation labels
+        batch_size (int): the batch size
+        epochs (int): the number of epochs
+    """
     # Warn user if number of epochs is not a multiple of 8
     if epochs % 8:
         print("WARNING: for better performance, the number of epochs "
@@ -103,12 +125,21 @@ def train_model(model, x_train, y_train, x_val, y_val, batch_size, epochs):
 
 
 def evaluate_model(model, x_val, y_val):
+    """ Evaluates model performances.
+
+    Args:
+        model (tf.Keras.Model): the model to evaluate
+        x_val (numpy.ndarray): evaluation data
+        y_val (numpy.ndarray): evaluation labels
+    """
     model = compile_model(model)
     _, accuracy = model.evaluate(x_val, to_categorical(y_val), verbose=0)
     print('Validation accuracy:', accuracy)
 
 
 def main():
+    """ Entry point for script and CLI usage.
+    """
     parser = argparse.ArgumentParser()
     parser.add_argument("-m",
                         "--model",
