@@ -15,7 +15,7 @@
 # limitations under the License.
 # ******************************************************************************
 """
- UTKFace model training script
+Training script for UTKFace model.
 """
 
 # System imports
@@ -30,6 +30,16 @@ from akida_models.utk_face.preprocessing import load_data
 
 
 def get_rescaled_data_set(x_train, x_test, input_scaling):
+    """ Rescales UTKFace dataset.
+
+    Args:
+        x_train (numpy.ndarray): train data
+        x_test (numpy.ndarray): test data
+        input_scaling (tuple): rescale factor and bias
+
+    Returns:
+        tuple: train and test data
+    """
     a, b = input_scaling
 
     x_train = x_train.astype('float32')
@@ -42,7 +52,17 @@ def get_rescaled_data_set(x_train, x_test, input_scaling):
 
 
 def train_model(model, x_train, y_train, x_test, y_test, epochs, batch_size):
+    """ Trains the model.
 
+    Args:
+        model (tf.Keras.Model): the model to train
+        x_train (numpy.ndarray): train data
+        y_train (numpy.ndarray): train labels
+        x_test (numpy.ndarray): test data
+        y_test (numpy.ndarray): test labels
+        epochs (int):  the number of epochs
+        batch_size (int): the batch size
+    """
     # Learning rate: be more aggressive at the beginning, and apply decay
     lr_start = 1e-3
     lr_end = 1e-4
@@ -54,17 +74,23 @@ def train_model(model, x_train, y_train, x_test, y_test, epochs, batch_size):
     # Compile model
     model.compile(optimizer='adam', loss='mae')
 
-    history = model.fit(x_train,
-                        y_train,
-                        batch_size=batch_size,
-                        epochs=epochs,
-                        verbose=1,
-                        validation_data=(x_test, y_test),
-                        callbacks=callbacks)
+    model.fit(x_train,
+              y_train,
+              batch_size=batch_size,
+              epochs=epochs,
+              verbose=1,
+              validation_data=(x_test, y_test),
+              callbacks=callbacks)
 
 
 def evaluate_model(model, x_test, y_test):
+    """ Evaluates model performances.
 
+    Args:
+        model (tf.Keras.Model): the model to evaluate
+        x_test (numpy.ndarray): evaluation data
+        y_test (numpy.ndarray): evaluation labels
+    """
     # Compile model
     model.compile(optimizer='adam', loss='mae')
 
@@ -73,7 +99,8 @@ def evaluate_model(model, x_test, y_test):
 
 
 def main():
-
+    """ Entry point for script and CLI usage.
+    """
     parser = argparse.ArgumentParser()
     parser.add_argument("-m",
                         "--model",
